@@ -9,9 +9,9 @@
 #include "dhtbase.h"
 #include "key.h"
 #include "rpcmsg.h"
-#include <qmap.h>
-#include <qstring.h>
-#include <qtimer.h>
+#include <QMap>
+#include <QString>
+#include <QTimer>
 #include <util/constants.h>
 #include <util/timer.h>
 
@@ -41,8 +41,8 @@ class FindNodeReq;
 class GetPeersReq;
 class AnnounceReq;
 
-/**
-    @author Joris Guisson <joris.guisson@gmail.com>
+/*!
+    \author Joris Guisson <joris.guisson@gmail.com>
 */
 class DHT : public DHTBase
 {
@@ -59,38 +59,38 @@ public:
     void error(const ErrMsg &r);
     void timeout(RPCMsg::Ptr r);
 
-    /**
+    /*!
      * A Peer has received a PORT message, and uses this function to alert the DHT of it.
-     * @param ip The IP of the peer
-     * @param port The port in the PORT message
+     * \param ip The IP of the peer
+     * \param port The port in the PORT message
      */
     void portReceived(const QString &ip, bt::Uint16 port) override;
 
-    /**
+    /*!
      * Do an announce on the DHT network
-     * @param info_hash The info_hash
-     * @param port The port
-     * @return The task which handles this
+     * \param info_hash The info_hash
+     * \param port The port
+     * \return The task which handles this
      */
     AnnounceTask *announce(const bt::SHA1Hash &info_hash, bt::Uint16 port) override;
 
-    /**
+    /*!
      * Refresh a bucket using a find node task.
-     * @param id The id
-     * @param bucket The bucket to refresh
+     * \param id The id
+     * \param bucket The bucket to refresh
      */
     NodeLookup *refreshBucket(const dht::Key &id, KBucket &bucket);
 
-    /**
+    /*!
      * Do a NodeLookup.
-     * @param id The id of the key to search
+     * \param id The id of the key to search
      */
     NodeLookup *findNode(const dht::Key &id);
 
-    /// Do a findNode for our node id
+    //! Do a findNode for our node id
     NodeLookup *findOwnNode();
 
-    /// See if it is possible to start a task
+    //! See if it is possible to start a task
     bool canStartTask() const;
 
     void start(const QString &table, const QString &key_file, bt::Uint16 port) override;
@@ -99,7 +99,7 @@ public:
 
     QMap<QString, int> getClosestGoodNodes(int maxNodes) override;
 
-    /// Bootstrap from well-known nodes
+    //! Bootstrap from well-known nodes
     void bootstrap();
 
 private Q_SLOTS:
