@@ -11,6 +11,7 @@
 #include <util/log.h>
 
 using namespace bt;
+using namespace Qt::Literals::StringLiterals;
 
 namespace dht
 {
@@ -47,9 +48,9 @@ void ErrMsg::parse(BDictNode *dict)
     RPCMsg::parse(dict);
     BListNode *ln = dict->getList(ERR_DHT);
     if (!ln)
-        throw bt::Error("Invalid error message");
+        throw bt::Error(u"Invalid error message"_s);
 
-    msg = ln->getString(1, nullptr);
+    msg = ln->getString(1);
 }
 
 }
