@@ -70,19 +70,17 @@ public:
 };
 
 ChunkManager::ChunkManager(Torrent &tor, const QString &tmpdir, const QString &datadir, bool custom_output_name, CacheFactory *fac)
-    : d(nullptr)
+    : d(std::make_unique<Private>(this, tor, tmpdir, datadir, custom_output_name, fac))
     , tor(tor)
     , bitset(tor.getNumChunks())
     , excluded_chunks(tor.getNumChunks())
     , only_seed_chunks(tor.getNumChunks())
 {
-    d = new Private(this, tor, tmpdir, datadir, custom_output_name, fac);
     d->setupPriorities();
 }
 
 ChunkManager::~ChunkManager()
 {
-    delete d;
 }
 
 QString ChunkManager::getDataDir() const
@@ -995,7 +993,7 @@ void ChunkManager::Private::doPreviewPriority(TorrentFile &file)
 
 bool ChunkManager::Private::allFilesExistOfChunk(Uint32 idx)
 {
-    QList<Uint32> files;
+    Torrent::FileIndexList files;
     Torrent &tor = p->tor;
     tor.calcChunkPos(idx, files);
     for (Uint32 fidx : std::as_const(files)) {
@@ -1048,7 +1046,7 @@ void ChunkManager::Private::dumpPriority(TorrentFile *tf)
 
 void ChunkManager::Private::setBorderChunkPriority(Uint32 idx, Priority prio)
 {
-    QList<Uint32> files;
+    Torrent::FileIndexList files;
     Torrent &tor = p->tor;
     Priority highest = prio;
     // get list of files where first chunk lies in
@@ -1065,7 +1063,7 @@ void ChunkManager::Private::setBorderChunkPriority(Uint32 idx, Priority prio)
 
 bool ChunkManager::Private::resetBorderChunk(Uint32 idx, TorrentFile *tf)
 {
-    QList<Uint32> files;
+    Torrent::FileIndexList files;
     Torrent &tor = p->tor;
     tor.calcChunkPos(idx, files);
     for (Uint32 file : std::as_const(files)) {
