@@ -33,7 +33,7 @@ private Q_SLOTS:
     void initTestCase()
     {
         QLocale::setDefault(QLocale(u"main"_s));
-        bt::InitLibKTorrent();
+        QVERIFY(bt::InitLibKTorrent());
         bt::InitLog(u"chunkmanagertest.log"_s, false, true);
         QMap<QString, bt::Uint64> files;
 
