@@ -16,109 +16,96 @@
 
 namespace bt
 {
-static Uint8 *AllocPacket(Uint32 size, Uint8 type)
+Packet::Packet(Uint32 size, Uint8 type) noexcept
+    : size(size)
+    , written(0)
+    , type(type)
 {
-    Uint8 *data = new Uint8[size];
+    Uint8 *data = getData();
     WriteUint32(data, 0, size - 4);
     data[4] = type;
-    return data;
 }
 
-Packet::Packet(Uint8 type)
-    : data(nullptr)
-    , size(5)
-    , written(0)
-    , type(type)
+Packet::Ptr Packet::create(Uint8 type)
 {
-    data = AllocPacket(size, type);
+    constexpr Uint32 size = 5;
+    return Ptr(new (size) Packet(size, type));
 }
 
-Packet::Packet(Uint16 port)
-    : data(nullptr)
-    , size(7)
-    , written(0)
-    , type(PORT)
+Packet::Ptr Packet::create(Uint16 port)
 {
-    data = AllocPacket(size, PORT);
-    WriteUint16(data, 5, port);
+    constexpr Uint32 size = 7;
+    Ptr pkt(new (size) Packet(size, PORT));
+    WriteUint16(pkt->getData(), 5, port);
+    return pkt;
 }
 
-Packet::Packet(Uint32 chunk, Uint8 type)
-    : data(nullptr)
-    , size(9)
-    , written(0)
-    , type(type)
+Packet::Ptr Packet::create(Uint32 chunk, Uint8 type)
 {
-    data = AllocPacket(size, type);
-    WriteUint32(data, 5, chunk);
+    constexpr Uint32 size = 9;
+    Ptr pkt(new (size) Packet(size, type));
+    WriteUint32(pkt->getData(), 5, chunk);
+    return pkt;
 }
 
-Packet::Packet(const BitSet &bs)
-    : data(nullptr)
-    , size(5 + bs.getNumBytes())
-    , written(0)
-    , type(BITFIELD)
+Packet::Ptr Packet::create(const BitSet &bs)
 {
-    data = AllocPacket(size, BITFIELD);
-    memcpy(data + 5, bs.getData(), bs.getNumBytes());
+    const Uint32 size = 5 + bs.getNumBytes();
+    Ptr pkt(new (size) Packet(size, BITFIELD));
+    memcpy(pkt->getData() + 5, bs.getData(), bs.getNumBytes());
+    return pkt;
 }
 
-Packet::Packet(const Request &r, Uint8 type)
-    : data(nullptr)
-    , size(17)
-    , written(0)
-    , type(type)
+Packet::Ptr Packet::create(const Request &r, Uint8 type)
 {
-    data = AllocPacket(size, type);
+    constexpr Uint32 size = 17;
+    Ptr pkt(new (size) Packet(size, type));
+    Uint8 *data = pkt->getData();
     WriteUint32(data, 5, r.getIndex());
     WriteUint32(data, 9, r.getOffset());
     WriteUint32(data, 13, r.getLength());
+    return pkt;
 }
 
-Packet::Packet(Uint32 index, Uint32 begin, Uint32 len, Chunk *ch)
-    : data(nullptr)
-    , size(13 + len)
-    , written(0)
-    , type(PIECE)
+Packet::Ptr Packet::create(Uint32 index, Uint32 begin, Uint32 len, Chunk *ch)
 {
-    data = AllocPacket(size, PIECE);
+    const Uint32 size = 13 + len;
+    Ptr pkt(new (size) Packet(size, PIECE));
+    Uint8 *data = pkt->getData();
     WriteUint32(data, 5, index);
     WriteUint32(data, 9, begin);
     ch->readPiece(begin, len, data + 13);
+    return pkt;
 }
 
-Packet::Packet(Uint8 ext_id, const QByteArray &ext_data)
-    : data(nullptr)
-    , size(6 + ext_data.size())
-    , written(0)
-    , type(EXTENDED)
+Packet::Ptr Packet::create(Uint8 ext_id, const QByteArray &ext_data)
 {
-    data = AllocPacket(size, EXTENDED);
+    const Uint32 size = 6 + ext_data.size();
+    Ptr pkt(new (size) Packet(size, EXTENDED));
+    Uint8 *data = pkt->getData();
     data[5] = ext_id;
     memcpy(data + 6, ext_data.data(), ext_data.size());
-}
-
-Packet::~Packet()
-{
-    delete[] data;
+    return pkt;
 }
 
 bool Packet::isPiece(const Request &req) const
 {
+    const Uint8 *data = getData();
     return (data[4] == PIECE) && (ReadUint32(data, 5) == req.getIndex()) && (ReadUint32(data, 9) == req.getOffset()) && (size - 13 == req.getLength());
 }
 
-Packet *Packet::makeRejectOfPiece()
+Packet::Ptr Packet::makeRejectOfPiece() const
 {
     if (getType() != PIECE)
-        return nullptr;
+        return Ptr();
 
+    const Uint8 *data = getData();
     Uint32 idx = bt::ReadUint32(data, 5);
     Uint32 off = bt::ReadUint32(data, 9);
     Uint32 len = size - 13;
 
     //  Out(SYS_CON|LOG_DEBUG) << "Packet::makeRejectOfPiece " << idx << " " << off << " " << len << endl;
-    return new Packet(Request(idx, off, len, nullptr), bt::REJECT_REQUEST);
+    return create(Request(idx, off, len, nullptr), bt::REJECT_REQUEST);
 }
 
 /*
@@ -142,10 +129,6 @@ QString Packet::debugString() const
     }
 }
 */
-bool Packet::isOK() const
-{
-    return bool(data);
-}
 
 int Packet::send(net::SocketDevice *sock, Uint32 max_to_send)
 {
@@ -155,7 +138,7 @@ int Packet::send(net::SocketDevice *sock, Uint32 max_to_send)
 
     if (bw > max_to_send && max_to_send > 0)
         bw = max_to_send;
-    int ret = sock->send(data + written, bw);
+    int ret = sock->send(getData() + written, bw);
     if (ret > 0)
         written += ret;
     return ret;
