@@ -12,8 +12,8 @@
 
 namespace net
 {
-/**
- * @author Joris Guisson <joris.guisson@gmail.com>
+/*!
+ * \author Joris Guisson <joris.guisson@gmail.com>
  *
  * Thread which processes incoming data
  */
@@ -23,27 +23,27 @@ public:
     DownloadThread(SocketMonitor *sm);
     ~DownloadThread() override;
 
-    /// Wake up the download thread
+    //! Wake up the download thread
     void wakeUp();
 
-    /// Set the download cap
+    //! Set the download cap
     static void setCap(bt::Uint32 cap)
     {
         dcap = cap;
     }
 
-    /// Get the download cap
-    static Uint32 cap()
+    //! Get the download cap
+    static bt::Uint32 cap()
     {
         return dcap;
     }
 
-    /// Set the sleep time when using download caps
+    //! Set the sleep time when using download caps
     static void setSleepTime(bt::Uint32 stime);
 
 private:
     void update() override;
-    bool doGroup(SocketGroup *g, Uint32 &allowance, bt::TimeStamp now) override;
+    bool doGroup(SocketGroup *g, bt::Uint32 &allowance, bt::TimeStamp now) override;
     int waitForSocketReady();
 
 private:
